@@ -3,7 +3,7 @@
 ##   Cleven  -  a user interface of aircrack-ng for the N900    ##
 ##################################################################
 #                                                                #
-# Copyright (c) 2011 Christos Zamantzas                          #
+# Copyright (c) 2011-2012 Christos Zamantzas                     #
 # Licenced under GPLv2                                           #
 #                                                                # 
 # Christos Zamantzas (Saturn) <christos.zamantzas@gmail.com>     #
@@ -11,7 +11,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '2.5'
+Version = '3.0'
 Build = '1'
 
 import sys
@@ -375,25 +375,13 @@ class clevenConfigureDrivers(QtGui.QDialog):
        global kernelVersion
        kernelVersion = os.popen('uname -r').read().strip('\n').strip('')
        print "Version of Kernel found: ", kernelVersion
-       global driversVersion
-       driversVersion = '-v1'
               
-       if kernelVersion == '2.6.28.10power46-wl1':
+       if kernelVersion == '2.6.28.10-power50':
           pass
-       elif kernelVersion == '2.6.28.10-power47':
-          pass
-       elif kernelVersion == '2.6.28.10-power48':
-          pass
-       elif kernelVersion == '2.6.28.10-power49':
-          pass
-       elif kernelVersion == '2.6.28.10-power50':
-          driversVersion = '-v2'
        else: 
           message = 'WARNING: The system did not find a known compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
           showMessage(message)
 
-       print "Version of drivers chosen: ", driversVersion
-          
     def getDriversState(self):
        '''Check the state of the Drivers (Stock/Bleeding)'''
        
@@ -453,7 +441,7 @@ class clevenConfigureDrivers(QtGui.QDialog):
        message ='Loading the injection drivers..'
        showQuickMessage(message)
        
-       os.system('sudo %s/load.sh %s' % (pathMain,driversVersion))
+       os.system('sudo %s/load.sh %s' % (pathMain,kernelVersion))
        self.getDriversState()
        self.getInterfaceState()
        self.getMAC()
